/*******************
VARIABLES
*******************/
var videoRef, useractionBtn, clickthroughBtn, transparentClickthrough, buttonContainer;
var isLocal = false;
var isMobile = false;
var isIOS = false;
//the unsupportedBrowser are the browsers which are not compatible with autoplay of the video.
//In this cases, the image background will be shown and when the Ad is expanded the user can watch the video
var isUnsupportedBrowserAutoPlay = false;
/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(e) {
	adkit.onReady(initializeCreative);
}

function initializeCreative() {
	initializeGlobalVariables();
	addEventListeners();
}

function initializeGlobalVariables() {
	//getInfo will return info if is the ad is in Local or if is a mobile device or if the autoplay is supported
	var infoDevice = immersiveTakeover.getInfo();
	isLocal = infoDevice.isLocal;
	isMobile = infoDevice.isMobile;
	isUnsupportedBrowserAutoPlay = infoDevice.isUnsupportedBrowserAutoPlay;
	isIOS = infoDevice.isIOS;

	buttonContainer = document.getElementById("button-container");
	useractionBtn = document.getElementById("useraction-button");
	clickthroughBtn = document.getElementById("clickthrough-button");
	transparentClickthrough = document.getElementById("transparent-clickthrough");
}

function addEventListeners() {
	useractionBtn.addEventListener("click", onUserAction);
	clickthroughBtn.addEventListener("click", onClickthrough);
	transparentClickthrough.addEventListener("click", onClickthrough);
}
/*******************
CREATIVE FUNCTIONS
*******************/
function onUserAction(e) {
	EB.userActionCounter("CustomInteraction");
}

function onClickthrough(e) {
	EB.clickthrough("click_background");
}

function pauseVideo() {
	videoRef.pause();
}

function playVideo() {
	showVideo();
	setTimeout(function() {
		videoRef.play();
	}, 200);
}

function onToggleVideoPlay(e) {
	if (!e.playVideo) {
		pauseVideo();
	}
	else {
		showVideo();
		playVideo();
	}
}

function onToggleAudioControls(e) {
	if (!e.muteAudio) {
		videoRef.muted = false;
	}
	else {
		videoRef.muted = true;
	}
}

function hideVideo() {
	videoRef.style.opacity = "0";
}

function showVideo() {
	videoRef.style.opacity = "1";
}
/*******************
CALLBACK FUNCTIONS
*******************/
function afterShowPanelContent(args) {
	//Implement code logic to fire when the panel is shown
	if (isMobile && !isUnsupportedBrowserAutoPlay) {
		buttonContainer.style.display = "none";
	}
}

function afterExpandAnimStart(args) {
	//Implement code logic to fire when panel expand animation start
	if (isMobile && isUnsupportedBrowserAutoPlay) {
		buttonContainer.style.display = "block";
		transparentClickthrough.style.display = "none";

		showVideo();
	}

	showVideo();

	setTimeout(function() {

		if (!args.isAutoExpand) {
			videoRef.muted = false;
			videoRef.play();
		}
	}, 200);
}

function afterExpandAnimComplete(args) {
	//Implement code logic to fire when panel expand animation complete
}

function afterCollapseAnimStart(args) {
	//Implement code logic to fire when panel collapse animation start
}

function afterCollapseAnimComplete(args) {
	//Implement code logic to fire when panel collapse animation complete
	if (isMobile && isUnsupportedBrowserAutoPlay) {
		pauseVideo();
		hideVideo();
	}
	else {
		//if you want to pause the video when the video Skin is collapsed in Desktop
		pauseVideo();
	}
	if (isMobile) {
		buttonContainer.style.display = "none";
	}
}

function afterAnimationEnd(args) {
	//Implement code logic to fire when panel Animation End
}

function adWasClicked(args) {
	if (isMobile && !isUnsupportedBrowserAutoPlay) {
		if (args.isExpanded) {
			buttonContainer.style.display = "block";
		}
	}
	if (isMobile && !isIOS) {
		var isMuted = videoRef.muted;
		videoRef.load();
		setTimeout(function() {
			videoRef.muted = isMuted;
			pauseVideo();
		}, 100);
	}
	else {
		pauseVideo();
	}

	if (!isMobile || !isUnsupportedBrowserAutoPlay) {
		hideVideo();
	}
}
/*******************
CALLBACK VIDEO FUNCTIONS
*******************/
function afterVideoReady(args) {
	//Implement code logic to fire when the video ready / video tag injected into the page
	videoRef = args.video;
}

function afterVideoEnd(args) {
	//Implement code logic to fire when the video End
	if (isMobile && !isUnsupportedBrowserAutoPlay) {
		if (args.isExpanded) {
			buttonContainer.style.display = "block";
		}
	}
	hideVideo();
}

function afterVideoPlay(args) {
	//Implement code logic to fire when the video Play
	if (isMobile && !isUnsupportedBrowserAutoPlay) {
		buttonContainer.style.display = "none";
	}
}

function afterVideoPause(args) {
	//Implement code logic to fire when the video Pause
}

function afterVolumeChange(args) {
	//Implement code logic to fire when the volume Change
}
/*******************
END OF CREATIVE FUNCTIONS
*******************/
//config = {
//		panel: define the type of the element for the immersiveTakeover, //options: header, left_gutter, right_gutter, background, videoskin, controls or standard
// In the case you want to use the resizeVideo function in the panel with video to get a good aspectRatio, you will need:
//      videoWidth: width of your video,
//      videoHeight: height of your video
// To set video source URL use the following.
// For single video codec use a string as the value.  EG: videoPoster: "videos/video1.jpg"
// For multiple video codecs use an array.  EG: videoPoster: ["videos/video1.mp4", "videos/video1.webm"]
//		videoURL: "videos/video1.mp4",
// To set video poster image source URL use the following.
//		videoPoster: "videos/video1.jpg"
//};
var config = {
	panel: "videoskin",
	videoWidth: 1100,
	videoHeight: 416,
	videoURL: "videos/video1.mp4", // For multiple codecs use an array.  EG: ["videos/video1.mp4", "videos/video1.webm"]
	videoPoster: "videos/video1.jpg"
};
var immersiveTakeover = new immersiveTakeover(config);
window.addEventListener("load", checkIfAdKitReady);
