/*******************
	VARIABLES
*******************/
var playBtn, pauseBtn, audioToggle, expandBtn, collapseBtn, panel, videoToggle, btnStateInterval;
var isUnsupportedBrowserAutoPlay = false;
var isLocal = false;
var isMobile = false;
var isVideoPlaying = false;
var isAudioMute = true;
var isExpanded = false;
var isAutoExpanded = false;
var pnlExpOrClpsInProg = false;
/*******************
	INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	adkit.onReady(initializeCreative);
}

function initializeCreative() {
	initializeGlobalVariables();
	addEventListeners();
}

function initializeGlobalVariables() {
	//getInfo will return info if is the ad is in Local or if is a mobile device or if the autoplay is supported
	var infoDevice = immersiveTakeover.getInfo();
	isLocal = infoDevice.isLocal;
	isMobile = infoDevice.isMobile;
	isUnsupportedBrowserAutoPlay = infoDevice.isUnsupportedBrowserAutoPlay;

	panel = document.getElementById("panel");
	expandBtn = document.getElementById("expand-button");
	collapseBtn = document.getElementById("collapse-button");
	audioToggle = document.getElementById("audio-toggle");
	stateToggle = document.getElementById("state-toggle");
	videoToggle = document.getElementById("video-toggle");
	if (isMobile && isUnsupportedBrowserAutoPlay) {
		hideVideoControls();
	}
	else {
		isVideoPlaying = true;
		updatePlayBtnState();
	}
}

function addEventListeners() {
	videoToggle.addEventListener("click", onPlayToggleClick);
	audioToggle.addEventListener("click", onAudioClick);
	stateToggle.addEventListener("click", onStateToggleClick);
}
/*******************
	EVENT HANDLERS
*******************/
function onPlayToggleClick(e) {
	if (pnlExpOrClpsInProg === true) {
		return;
	}

	isVideoPlaying = !isVideoPlaying;
	updatePlayBtnState();
	//toggleVideoPlay: will change the state of the video play/pause
	immersiveTakeover.toggleVideoPlay(isVideoPlaying);
}

function onStateToggleClick(e) {
	if (pnlExpOrClpsInProg === true) {
		return;
	}

	isExpanded = !isExpanded;
	if (isExpanded) {
		immersiveTakeover.onExpandClick();
		updatePanelState();
		isVideoPlaying = true;
		isAudioMute = true;
		updatePlayBtnState();
		onAudioToggle();
	}
	else {
		immersiveTakeover.onCollapseClick();
		updatePanelState();
	}
}

function onAudioClick() {
	if (pnlExpOrClpsInProg === true) {
		return;
	}

	if (isAudioMute && !isExpanded) {
		//onExpandClick: will expand the videowall
		immersiveTakeover.onExpandClick();
	}
	onAudioToggle();
}

function onAudioToggle() {
	isAudioMute = !isAudioMute;
	if (!isAudioMute && !isExpanded) {
		isVideoPlaying = true;
		updatePlayBtnState();
	}
	updateAudioBtnState();
	//toggleAudio: will change the state of the video mute/unmute
	immersiveTakeover.toggleAudio(isAudioMute);
}
/*******************
	CREATIVE FUNCTIONS
*******************/
function updatePlayBtnState() {
	if (isVideoPlaying) {
		videoToggle.classList.remove("play");
		videoToggle.classList.add("pause");
	}
	else {
		videoToggle.classList.remove("pause");
		videoToggle.classList.add("play");
	}
}

function updateAudioBtnState() {
	if (isAudioMute) {
		audioToggle.classList.remove("unmute");
		audioToggle.classList.add("mute");
	}
	else {
		audioToggle.classList.remove("mute");
		audioToggle.classList.add("unmute");
	}
}

function updatePanelState() {
	if (isExpanded) {
		expandBtn.style.display = "none";
		collapseBtn.style.display = "block";
	}
	else {
		expandBtn.style.display = "block";
		collapseBtn.style.display = "none";
	}
}

function updateExpandCollapseState(args) {
	isExpanded = args.isExpanded;
	updatePanelState();
	if (args.isAutoExpand) {
		isVideoPlaying = true;
		updatePlayBtnState();
	}
}

function showVideoControls() {
	try {
		videoToggle.style.display = "inline-block";
		updatePlayBtnState();
		clearInterval(btnStateInterval);
		if (isMobile && isUnsupportedBrowserAutoPlay) {
			btnStateInterval = setInterval(updatePlayBtnState, 1000);
		}
		else {
			audioToggle.style.display = "block";
		}
		panel.classList.remove("panel-controls-off");
		panel.classList.add("panel-controls-on");
	}
	catch (e) {}
}

function hideVideoControls() {
	videoToggle.style.display = "none";
	audioToggle.style.display = "none";
	stateToggle.classList.add("state-toggle-unsupported");
	panel.classList.add("panel-controls-off");
}
/*******************
CALLBACK FUNCTIONS
*******************/
function afterShowPanelContent(args) {
	//Implement code logic to fire when the panel is shown
}

function afterExpandAnimStart(args) {
	//Implement code logic to fire when panel expand animation start
	pnlExpOrClpsInProg = true;
}

function afterExpandAnimComplete(args) {
	//Implement code logic to fire when panel expand animation complete
	pnlExpOrClpsInProg = false;
}

function afterCollapseAnimStart(args) {
	//Implement code logic to fire when panel collapse animation start
	pnlExpOrClpsInProg = true;
}

function afterCollapseAnimComplete(args) {
	//Implement code logic to fire when panel collapse animation complete
	pnlExpOrClpsInProg = false;
}

function adWasClicked(args) {
	pnlExpOrClpsInProg = false;
	isVideoPlaying = false;
	updatePlayBtnState();
}
/*******************
CALLBACK VIDEO FUNCTIONS
*******************/
function afterVideoEnd(args) {
	//Implement code logic to fire when the video End
}

function afterVideoPlay(args) {
	//Implement code logic to fire when the video Play
	if (isMobile && !isUnsupportedBrowserAutoPlay) {
		showVideoControls();
		isVideoPlaying = true;
		updatePlayBtnState();
	}
}

function afterVideoPause(args) {
	//Implement code logic to fire when the video Pause
	isVideoPlaying = false;
	updatePlayBtnState();
	setTimeout(updatePlayBtnState, 300);
}

function afterVolumeChange(args) {
	//Implement code logic to fire when the volume Change
	if (typeof args !== "undefined") {
		isAudioMute = args.isAudioMute;
	}
	updateAudioBtnState();
}
/*******************
END OF CREATIVE FUNCTIONS
*******************/
//config = {    panel: define the type of the element for the immersiveTakeover, //options: header, left_gutter, right_gutter, background, videoskin, controls or standard
//in the case you want to use the resizeVideo function in the panel with video to get a good aspectRatio, you will need:
//     	videoWidth: width of your video,
//		videoHeight: height of your video,
//		initialPosition: the first position of the controls panel when the Ad is loaded,
//		expandedPosition: the position of the controls panel when the VideoSkin is expanded,
//		collapsedPosition: the position of the controls panel after the VideoSkin is collapsed
//};
var config = {
	panel: "controls",
	initialPosition: "top-center",
	expandedPosition: "top-center",
	collapsedPosition: "top-center"
};
var immersiveTakeover = new immersiveTakeover(config);
window.addEventListener("load", checkIfAdKitReady);
